Struct network::application::storage::LockingHashMap [−][src]
pub struct LockingHashMap<Key: Clone + Debug + Eq + Hash, Value: Clone + Debug> { /* fields omitted */ }Expand description
A generic locking hash map with ability to read before write consistency
Implementations
Filtered read clone based on keys or values
Take in a function to modify the data, must handle concurrency control with the input function
Get the underlying RwLock of the map. Usage is discouraged as it leads to the possiblity of
leaving the lock held for a long period of time. However, not everything fits into the write
model.